@@ -8,7 +8,7 @@ dwiQball <- function(object,  ...) cat("No DWI Q-ball calculation defined for th
 
 setGeneric("dwiQball", function(object,  ...) standardGeneric("dwiQball"))
 
-setMethod("dwiQball","dtiData",function(object,what="ODF",order=4,lambda=0){
+setMethod("dwiQball","dtiData",function(object,what="wODF",order=4,lambda=0){
   args <- sys.call(-1)
   args <- c(object@call,args)
   if (!(what %in% c("ODF","wODF","aODF","ADC"))) {
@@ -20,7 +20,7 @@ setMethod("dwiQball","dtiData",function(object,what="ODF",order=4,lambda=0){
   ns0 <- length(s0ind)
   sdcoef <- object@sdcoef
   z <- .Fortran("outlier",
-                as.integer(object@si),
+                as.double(object@si),
                 as.integer(prod(ddim)),
                 as.integer(ngrad),
                 as.logical((1:ngrad)%in%s0ind),
@@ -215,6 +215,7 @@ setMethod("dwiQball","dtiData",function(object,what="ODF",order=4,lambda=0){
                 voxelext = object@voxelext,
                 level = object@level,
                 orientation = object@orientation,
+                rotation = object@rotation,
                 source = object@source,
                 outlier = index,
                 scale = 0.5,
